import fs from 'fs';
import _ from 'lodash';
import moment from 'moment';
import findLogPath from './find-log-path';

var format = 'YYYY-MM-DD';

export default function (howManyDaysAgo, appName) {
  var path = findLogPath(appName);
  var files = [];
  try {
    files = fs.readdirSync(path);
  } catch (e) {
    return null;
  }

  _.forEach(files, function (file, index) {
    var yearMonthDay = getYearMonthDay(file);
    if (!yearMonthDay) {
      return;
    }

    if (!isBefore(howManyDaysAgo, yearMonthDay)) {
      return;
    }

    deleteLogFile(path + file);
  });
}

function getYearMonthDay(file) {
  var split = _.split(file, '-', 3);
  if (split.length < 3) {
    return null;
  }

  return {
    year: split[0],
    month: split[1],
    day: _.split(split[2], '_', 1)[0]
  };
}

function isBefore(howManyDaysAgo, yearMonthDay) {
  var agoDays = moment(moment().format(format)).subtract(howManyDaysAgo, 'days');
  var fileDays = moment([yearMonthDay.year, yearMonthDay.month, yearMonthDay.day].join('-'));
  return moment(fileDays).isBefore(agoDays);
}

function deleteLogFile(filePath) {
  try {
    fs.unlinkSync(filePath);
  } catch (e) {
    return null;
  }
}