'use strict';

exports.__esModule = true;

exports.default = function () {
  var appName = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';

  var dir = void 0;
  switch (process.platform) {
    case 'linux':
      dir = prepareDir(process.env['XDG_CONFIG_HOME'], appName).or(process.env['HOME'] + '/.config', appName).or(process.env['XDG_DATA_HOME'], appName).or(process.env['HOME'] + '/.local/share', appName).result;
      break;
    case 'darwin':
      dir = prepareDir(process.env['HOME'] + '/Library/Logs', appName).or(process.env['HOME'] + '/Library/Application Support', appName).result;
      break;
    case 'win32':
      dir = prepareDir(process.env['APPDATA'], appName).or(process.env['HOME'] + '/AppData', appName).result;
      break;
    default:
      break;
  }

  return [dir, '/'].join('');
};

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function prepareDir(path, appName) {
  if (!this || this.or !== prepareDir || !this.result) {
    if (!path) {
      return { or: prepareDir };
    }
    path = path + '/' + appName;
    mkDir(path);
    try {
      _fs2.default.accessSync(path, _fs2.default.W_OK);
    } catch (e) {
      return { or: prepareDir };
    }
  }

  return {
    or: prepareDir,
    result: (this ? this.result : false) || path
  };
}

function mkDir(path, root) {
  var dirs = path.split('/');
  var dir = dirs.shift();
  root = (root || '') + dir + '/';

  try {
    _fs2.default.mkdirSync(root);
  } catch (e) {
    if (!_fs2.default.statSync(root).isDirectory()) {
      throw new Error(e);
    }
  }

  return !dirs.length || mkDir(dirs.join('/'), root);
}